@@ -1,5 +1,8 @@
 #!/bin/sh
 
+PATH=/bin
+export PATH
+
 Xconfig=/usr/X11R6/lib/X11 # obsolete base dir
 etcXconfig=/etc/X11	   # new base dir
 
